# mkdocs-curriculum-vitae

[![documentation](https://img.shields.io/badge/docs-mkdocs--curriculum--vitae-blue.svg?style=flat)](https://paul-riviere.github.io/mkdocs-curriculum-vitae/)
[![pypi](https://img.shields.io/pypi/v/mkdocs-curriculum-vitae.svg)](https://pypi.org/project/mkdocs-curriculum-vitae/)
[![downloads](https://img.shields.io/pypi/dm/mkdocs-curriculum-vitae.svg)](https://pypi.org/project/mkdocs-curriculum-vitae/)
[![license](https://img.shields.io/pypi/l/mkdocs-curriculum-vitae.svg)](https://pypi.python.org/pypi/mkdocs-curriculum-vitae)
[![gitpod-ready-to-code](https://img.shields.io/badge/gitpod-ready--to--code-blue?logo=gitpod)](https://gitpod.io/#https://github.com/Paul-Riviere/mkdocs-curriculum-vitae)

## Description

A MkDocs theme, made to build your own curriculum vitae.

This theme generates a single page, for now you cannot put other md files than the index. There isn't any navbar.

Currently you cannot configure grid layout, or colors. This will be implemented soon.

## Demo

You can see a [live exmple here](https://paul-riviere.github.io/mkdocs-curriculum-vitae-example/) and see how it is configured on [the demo project](https://github.com/Paul-Riviere/mkdocs-curriculum-vitae-example).

Here's an example with basic configuration :

![](docs/assets/themes/default.png)

## Usage

See [documentation](https://paul-riviere.github.io/mkdocs-curriculum-vitae/how-to-use-it/).

## Contributing

See [CONTRIBUTING.md](CONTRIBUTING.md) file.

## Credits

Thanks a lot to the amazing [NES.css](https://github.com/nostalgic-css/NES.css) project, that I used to create the nes theme. The css was adapted to this repo, and the icons were rebuilt with Piskel because the originals weren't compliant with the current html/css. Those icons helped me designing the other ones, such as X, Gitlab, and Tiktok.
